@@ -9,7 +9,7 @@
 ## provides two functions: meltGUI and castGUI.
 ## How to improve these?
 
-pmg.meltGUI = function(container = gwindow("Melt a data frame")) {
+pmg.meltGUI = function(container = pmgWC$new("Melt a data frame")) {
   if(!do.call("require",list("reshape"))) {
     cat("Need to install reshape package\n")
     return()
@@ -170,7 +170,7 @@ pmg.meltGUI = function(container = gwindow("Melt a data frame")) {
 }
 
 
-pmg.castGUI = function(container=gwindow("Cast data")) {
+pmg.castGUI = function(container=pmgWC$new("Cast data")) {
 
   if(!do.call("require",list("reshape"))) {
     cat("Need to install reshape package\n")
